@@ -114,6 +114,7 @@ struct _EEwsItemPrivate {
 	time_t date_received;
 	time_t date_sent;
 	time_t date_created;
+	time_t last_modified_time;
 
 	gsize size;
 	gchar *msg_id;
@@ -139,6 +140,7 @@ struct _EEwsItemPrivate {
 	EwsMailbox *sender;
 
 	gboolean is_meeting;
+	gboolean is_response_requested;
 	GSList *modified_occurrences;
 	GSList *attachments_ids;
 	gchar *my_response_type;
@@ -287,6 +289,7 @@ e_ews_item_init (EEwsItem *item)
 
 	item->priv->item_type = E_EWS_ITEM_TYPE_UNKNOWN;
 	item->priv->is_meeting = FALSE;
+	item->priv->is_response_requested = FALSE;
 
 	item->priv->mapi_extended_tags = g_hash_table_new_full (g_direct_hash, g_direct_equal, NULL, g_free);
 	item->priv->mapi_extended_sets = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, (GDestroyNotify) g_hash_table_destroy);
@@ -1553,6 +1556,8 @@ e_ews_item_set_from_soap_parameter (EEwsItem *item,
 			priv->date_sent = ews_item_parse_date (subparam);
 		} else if (!g_ascii_strcasecmp (name, "DateTimeCreated")) {
 			priv->date_created = ews_item_parse_date (subparam);
+		} else if (!g_ascii_strcasecmp (name, "LastModifiedTime")) {
+			priv->last_modified_time = ews_item_parse_date (subparam);
 		} else if (!g_ascii_strcasecmp (name, "HasAttachments")) {
 			value = e_soap_parameter_get_string_value (subparam);
 			priv->has_attachments = (!g_ascii_strcasecmp (value, "true"));
@@ -1626,6 +1631,10 @@ e_ews_item_set_from_soap_parameter (EEwsItem *item,
 			value = e_soap_parameter_get_string_value (subparam);
 			priv->is_meeting = (!g_ascii_strcasecmp (value, "true"));
 			g_free (value);
+		} else if (!g_ascii_strcasecmp (name, "IsResponseRequested")) {
+			value = e_soap_parameter_get_string_value (subparam);
+			priv->is_response_requested = (!g_ascii_strcasecmp (value, "true"));
+			g_free (value);
 		} else if (!g_ascii_strcasecmp (name, "MyResponseType")) {
 			g_free (priv->my_response_type);
 			priv->my_response_type = e_soap_parameter_get_string_value (subparam);
@@ -1853,6 +1862,14 @@ e_ews_item_get_date_created (EEwsItem *item)
 	return item->priv->date_created;
 }
 
+time_t
+e_ews_item_get_last_modified_time (EEwsItem *item)
+{
+	g_return_val_if_fail (E_IS_EWS_ITEM (item), -1);
+
+	return item->priv->last_modified_time;
+}
+
 gboolean
 e_ews_item_has_attachments (EEwsItem *item,
                             gboolean *has_attachments)
@@ -1883,6 +1900,14 @@ e_ews_item_get_is_meeting (EEwsItem *item)
 	return item->priv->is_meeting;
 }
 
+gboolean
+e_ews_item_get_is_response_requested (EEwsItem *item)
+{
+	g_return_val_if_fail (E_IS_EWS_ITEM (item), FALSE);
+
+	return item->priv->is_response_requested;
+}
+
 gboolean
 e_ews_item_is_forwarded (EEwsItem *item,
                          gboolean *forwarded)
